summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--.gitpod-files/loolwsd-gitpod.xml2
-rw-r--r--Makefile.am6
-rw-r--r--android/lib/src/main/java/org/libreoffice/androidlib/LOActivity.java2
-rw-r--r--browsersync-config.js4
-rw-r--r--configure.ac2
-rw-r--r--cypress_test/integration_tests/common/helper.js4
-rw-r--r--gtk/mobile.cpp2
-rw-r--r--indexing/Server.py2
-rw-r--r--ios/Mobile.xcodeproj/project.pbxproj8
-rw-r--r--ios/Mobile/CODocument.mm2
-rw-r--r--loleaflet/Makefile.am8
-rw-r--r--loleaflet/README6
-rw-r--r--loleaflet/html/cool.html.m4 (renamed from loleaflet/html/loleaflet.html.m4)0
-rw-r--r--loleaflet/html/framed.doc.html4
-rw-r--r--loleaflet/html/framed.html4
-rw-r--r--loleaflet/html/load.doc.html2
-rw-r--r--loleaflet/html/multidocs.html4
-rw-r--r--loleaflet/js/global.js2
-rw-r--r--loleaflet/src/map/handler/Map.WOPI.js2
-rw-r--r--loleaflet/test/load.js4
-rw-r--r--loolwsd.xml.in2
-rw-r--r--test/WhiteBoxTests.cpp4
-rw-r--r--test/integration-http-server.cpp8
-rw-r--r--wsd/FileServer.cpp8
-rw-r--r--wsd/LOOLWSD.cpp4
-rw-r--r--wsd/RequestDetails.cpp2
-rw-r--r--wsd/RequestDetails.hpp6
27 files changed, 52 insertions, 52 deletions
diff --git a/.gitpod-files/loolwsd-gitpod.xml b/.gitpod-files/loolwsd-gitpod.xml
index 2df65d2a6c..360c8ab037 100644
--- a/.gitpod-files/loolwsd-gitpod.xml
+++ b/.gitpod-files/loolwsd-gitpod.xml
@@ -45,7 +45,7 @@
<idle_timeout_secs desc="The maximum number of seconds before dimming and stopping updates when the user is no longer active (even if the browser is in focus). Defaults to 15 minutes." type="uint" default="900">900</idle_timeout_secs>
</per_view>
- <loleaflet_html desc="Allows UI customization by replacing the single endpoint of loleaflet.html" type="string" default="loleaflet.html">loleaflet.html</loleaflet_html>
+ <loleaflet_html desc="Allows UI customization by replacing the single endpoint of cool.html" type="string" default="cool.html">cool.html</loleaflet_html>
<logging>
<color type="bool">true</color>
diff --git a/Makefile.am b/Makefile.am
index ddce858915..e28e6c1682 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -455,13 +455,13 @@ run-one: setup-wsd
endif
sync-writer:
- browser-sync start --config browsersync-config.js --startPath "loleaflet/96c23f663/loleaflet.html?file_path=file://$(abs_top_srcdir)/test/data/hello-world.odt"
+ browser-sync start --config browsersync-config.js --startPath "loleaflet/96c23f663/cool.html?file_path=file://$(abs_top_srcdir)/test/data/hello-world.odt"
sync-calc:
- browser-sync start --config browsersync-config.js --startPath "loleaflet/96c23f663/loleaflet.html?file_path=file://$(abs_top_srcdir)/test/data/hello-world.ods"
+ browser-sync start --config browsersync-config.js --startPath "loleaflet/96c23f663/cool.html?file_path=file://$(abs_top_srcdir)/test/data/hello-world.ods"
sync-impress:
- browser-sync start --config browsersync-config.js --startPath "loleaflet/96c23f663/loleaflet.html?file_path=file://$(abs_top_srcdir)/test/data/hello-world.odp"
+ browser-sync start --config browsersync-config.js --startPath "loleaflet/96c23f663/cool.html?file_path=file://$(abs_top_srcdir)/test/data/hello-world.odp"
run-trace: setup-wsd
./loolwsd --o:sys_template_path="@SYSTEMPLATE_PATH@" \
diff --git a/android/lib/src/main/java/org/libreoffice/androidlib/LOActivity.java b/android/lib/src/main/java/org/libreoffice/androidlib/LOActivity.java
index facabb4433..8a02e783ac 100644
--- a/android/lib/src/main/java/org/libreoffice/androidlib/LOActivity.java
+++ b/android/lib/src/main/java/org/libreoffice/androidlib/LOActivity.java
@@ -825,7 +825,7 @@ public class LOActivity extends AppCompatActivity {
createLOOLWSD(dataDir, cacheDir, apkFile, assetManager, urlToLoad, uiMode, userName);
// trigger the load of the document
- String finalUrlToLoad = "file:///android_asset/dist/loleaflet.html?file_path=" +
+ String finalUrlToLoad = "file:///android_asset/dist/cool.html?file_path=" +
urlToLoad + "&closebutton=1";
// set the language
diff --git a/browsersync-config.js b/browsersync-config.js
index 9d82664085..611d6118fc 100644
--- a/browsersync-config.js
+++ b/browsersync-config.js
@@ -64,7 +64,7 @@ module.exports = {
"reloadThrottle": 0,
"plugins": [],
"injectChanges": true,
- "startPath": "loleaflet/04597b4ec/loleaflet.html?file_path=./test/data/hello-world.odt",
+ "startPath": "loleaflet/04597b4ec/cool.html?file_path=./test/data/hello-world.odt",
"minify": true,
"host": null,
"localOnly": false,
@@ -105,4 +105,4 @@ module.exports = {
"js": "script"
},
"injectNotification": false
-}; \ No newline at end of file
+};
diff --git a/configure.ac b/configure.ac
index 47c915b112..5042d26a41 100644
--- a/configure.ac
+++ b/configure.ac
@@ -1251,7 +1251,7 @@ AS_IF([test "$ENABLE_IOSAPP" = "true"],
(cd "$APP_BRANDING_DIR" && tar cf - .) | (cd ios/Mobile/Branding && tar xf -)
else
# A Branding/branding.css file must exist, it is
- # referenced unconditionally in loleaflet.html in the
+ # referenced unconditionally in cool.html in the
# iOS app.
touch ios/Mobile/Branding/branding.css
fi
diff --git a/cypress_test/integration_tests/common/helper.js b/cypress_test/integration_tests/common/helper.js
index f0131e3dbf..d457f85e8e 100644
--- a/cypress_test/integration_tests/common/helper.js
+++ b/cypress_test/integration_tests/common/helper.js
@@ -45,12 +45,12 @@ function loadTestDocNoIntegration(fileName, subFolder, noFileCopy, isMultiUser)
if (subFolder === undefined) {
URI += '/loleaflet/' +
Cypress.env('WSD_VERSION_HASH') +
- '/loleaflet.html?lang=en-US&file_path=file://' +
+ '/cool.html?lang=en-US&file_path=file://' +
Cypress.env('DATA_WORKDIR') + fileName;
} else {
URI += '/loleaflet/' +
Cypress.env('WSD_VERSION_HASH') +
- '/loleaflet.html?lang=en-US&file_path=file://' +
+ '/cool.html?lang=en-US&file_path=file://' +
Cypress.env('DATA_WORKDIR') + subFolder + '/' + fileName;
}
diff --git a/gtk/mobile.cpp b/gtk/mobile.cpp
index c61ca69f62..b944c820eb 100644
--- a/gtk/mobile.cpp
+++ b/gtk/mobile.cpp
@@ -327,7 +327,7 @@ int main(int argc, char* argv[])
fileURL = "file://" + FileUtil::realpath(argv[1]);
std::string urlAndQuery =
- "file://" TOPSRCDIR "/loleaflet/dist/loleaflet.html"
+ "file://" TOPSRCDIR "/loleaflet/dist/cool.html"
"?file_path=" + fileURL +
"&closebutton=1"
"&permission=edit"
diff --git a/indexing/Server.py b/indexing/Server.py
index 62dfb50a38..c4726543b0 100644
--- a/indexing/Server.py
+++ b/indexing/Server.py
@@ -17,7 +17,7 @@ coolServerUrl = "http://localhost:9980"
solrServerUrl = "http://localhost:8983"
documentPath = "Docs/"
-coolInstance = coolServerUrl + "/loleaflet/f6d368a0a/loleaflet.html"
+coolInstance = coolServerUrl + "/loleaflet/f6d368a0a/cool.html"
solrCollectionName = "documents"
# Templates
diff --git a/ios/Mobile.xcodeproj/project.pbxproj b/ios/Mobile.xcodeproj/project.pbxproj
index f8d27f934f..2845e162d7 100644
--- a/ios/Mobile.xcodeproj/project.pbxproj
+++ b/ios/Mobile.xcodeproj/project.pbxproj
@@ -7,7 +7,7 @@
objects = {
/* Begin PBXBuildFile section */
- BE00F8A021396585001CE2D4 /* loleaflet.html in Resources */ = {isa = PBXBuildFile; fileRef = BE00F89621396585001CE2D4 /* loleaflet.html */; };
+ BE00F8A021396585001CE2D4 /* cool.html in Resources */ = {isa = PBXBuildFile; fileRef = BE00F89621396585001CE2D4 /* cool.html */; };
BE00F8A121396585001CE2D4 /* bundle.css in Resources */ = {isa = PBXBuildFile; fileRef = BE00F89721396585001CE2D4 /* bundle.css */; };
BE00F8A321396585001CE2D4 /* bundle.js in Resources */ = {isa = PBXBuildFile; fileRef = BE00F89921396585001CE2D4 /* bundle.js */; };
BE00F8A721396585001CE2D4 /* loleaflet-help.html in Resources */ = {isa = PBXBuildFile; fileRef = BE00F89D21396585001CE2D4 /* loleaflet-help.html */; };
@@ -76,7 +76,7 @@
/* End PBXBuildFile section */
/* Begin PBXFileReference section */
- BE00F89621396585001CE2D4 /* loleaflet.html */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = text.html; name = loleaflet.html; path = ../../../loleaflet/dist/loleaflet.html; sourceTree = "<group>"; };
+ BE00F89621396585001CE2D4 /* cool.html */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = text.html; name = cool.html; path = ../../../loleaflet/dist/cool.html; sourceTree = "<group>"; };
BE00F89721396585001CE2D4 /* bundle.css */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = text.css; name = bundle.css; path = ../../../loleaflet/dist/bundle.css; sourceTree = "<group>"; };
BE00F89921396585001CE2D4 /* bundle.js */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.javascript; name = bundle.js; path = ../../../loleaflet/dist/bundle.js; sourceTree = "<group>"; };
BE00F89D21396585001CE2D4 /* loleaflet-help.html */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = text.html; name = "loleaflet-help.html"; path = "../../../loleaflet/dist/loleaflet-help.html"; sourceTree = "<group>"; };
@@ -1526,7 +1526,7 @@
BE00F89921396585001CE2D4 /* bundle.js */,
BE00F89E21396585001CE2D4 /* images */,
BE00F89D21396585001CE2D4 /* loleaflet-help.html */,
- BE00F89621396585001CE2D4 /* loleaflet.html */,
+ BE00F89621396585001CE2D4 /* cool.html */,
);
path = Resources;
sourceTree = "<group>";
@@ -3636,7 +3636,7 @@
BE18C7DE226DE09A001AD27E /* Branding in Resources */,
BE8D85D5214055F3009F1860 /* unorc in Resources */,
BE8D85D1214055F3009F1860 /* services.rdb in Resources */,
- BE00F8A021396585001CE2D4 /* loleaflet.html in Resources */,
+ BE00F8A021396585001CE2D4 /* cool.html in Resources */,
BE8D85CA214055F3009F1860 /* offapi.rdb in Resources */,
BE8D773A2136762600AC58EA /* Assets.xcassets in Resources */,
BE8D85CC214055F3009F1860 /* config in Resources */,
diff --git a/ios/Mobile/CODocument.mm b/ios/Mobile/CODocument.mm
index 7d96ec690e..4fc2a5b09b 100644
--- a/ios/Mobile/CODocument.mm
+++ b/ios/Mobile/CODocument.mm
@@ -69,7 +69,7 @@ static std::atomic<unsigned> appDocIdCounter(1);
if (error != nil)
return NO;
- NSURL *url = [[NSBundle mainBundle] URLForResource:@"loleaflet" withExtension:@"html"];
+ NSURL *url = [[NSBundle mainBundle] URLForResource:@"cool" withExtension:@"html"];
NSURLComponents *components = [NSURLComponents componentsWithURL:url resolvingAgainstBaseURL:NO];
DocumentData::allocate(appDocId).coDocument = self;
components.queryItems = @[ [NSURLQueryItem queryItemWithName:@"file_path" value:[copyFileURL absoluteString]],
diff --git a/loleaflet/Makefile.am b/loleaflet/Makefile.am
index 6a05407218..c22896748e 100644
--- a/loleaflet/Makefile.am
+++ b/loleaflet/Makefile.am
@@ -468,7 +468,7 @@ build-loleaflet: \
$(DIST_FOLDER)/device-tablet.css \
$(DIST_FOLDER)/device-desktop.css \
$(DIST_FOLDER)/bundle.js \
- $(DIST_FOLDER)/loleaflet.html
+ $(DIST_FOLDER)/cool.html
@echo "build loleaflet completed"
if ENABLE_ANDROIDAPP
@if test -d "$(APP_BRANDING_DIR)" ; then cp -a "$(APP_BRANDING_DIR)/branding.css" "$(APP_BRANDING_DIR)/branding.js" $(DIST_FOLDER)/ ; else touch $(DIST_FOLDER)/branding.css ; fi
@@ -518,13 +518,13 @@ $(DIST_FOLDER)/global.js: $(srcdir)/js/global.js
@mkdir -p $(dir $@)
$(call global_file)
-$(DIST_FOLDER)/loleaflet.html: $(srcdir)/html/loleaflet.html.m4 \
+$(DIST_FOLDER)/cool.html: $(srcdir)/html/cool.html.m4 \
$(LOLEAFLET_HTML_DST) \
$(LOLEAFLET_WELCOME_DST) \
$(DIST_FOLDER)/bundle.css \
$(DIST_FOLDER)/global.js \
$(DIST_FOLDER)/bundle.js
- @echo "Generating loleaflet.html..."
+ @echo "Generating cool.html..."
m4 -PE -DBUNDLE=$(IS_BUNDLE) \
-DENABLE_FEEDBACK=$(ENABLE_FEEDBACK) \
-DIOSAPP=$(ENABLE_IOSAPP) \
@@ -537,7 +537,7 @@ $(DIST_FOLDER)/loleaflet.html: $(srcdir)/html/loleaflet.html.m4 \
$(LOLEAFLET_LIBS_JS) \
$(patsubst %.ts,%.js,$(LOLEAFLET_JS_WEBORDER)))" \
-DVENDOR="$(VENDOR)" \
- $(srcdir)/html/loleaflet.html.m4 > $@
+ $(srcdir)/html/cool.html.m4 > $@
node_modules: package.json archived-packages
@npm install
diff --git a/loleaflet/README b/loleaflet/README
index d0fa5346de..a8086d5d44 100644
--- a/loleaflet/README
+++ b/loleaflet/README
@@ -83,9 +83,9 @@ Note that this will, by default, set the loolwsd's file server's root to the par
which means you can access all the files in loleaflet using /loleaflet/ path. It is advised to set
file_server_root_path manually for more control. See wsd/README for more information.
-* open dist/loleaflet.html through loolwsd's fileserver
+* open dist/cool.html through loolwsd's fileserver
- https://localhost:9980/loleaflet/dist/loleaflet.html?file_path=file:///PATH/TO_DOC&host=wss://localhost:9980
+ https://localhost:9980/loleaflet/dist/cool.html?file_path=file:///PATH/TO_DOC&host=wss://localhost:9980
and you should see the document in the browser.
Note that accessing local storage is disabled by default for security reasons. You need to explicitly enable it
@@ -114,7 +114,7 @@ make sync-[writer|calc|impress]
Your browser will open example document and now you can edit .css files and see the result without server restart.
To run another document use:
-browser-sync start --config browsersync-config.js --startPath "loleaflet/96c23f663/loleaflet.html?file_path=file:///path/to/the/file.ods"
+browser-sync start --config browsersync-config.js --startPath "loleaflet/96c23f663/cool.html?file_path=file:///path/to/the/file.ods"
Admin Panel
-----------
diff --git a/loleaflet/html/loleaflet.html.m4 b/loleaflet/html/cool.html.m4
index c230b3a88e..c230b3a88e 100644
--- a/loleaflet/html/loleaflet.html.m4
+++ b/loleaflet/html/cool.html.m4
diff --git a/loleaflet/html/framed.doc.html b/loleaflet/html/framed.doc.html
index 5d34cda250..e88b5c2f4e 100644
--- a/loleaflet/html/framed.doc.html
+++ b/loleaflet/html/framed.doc.html
@@ -1,6 +1,6 @@
<!DOCTYPE html>
-<!-- Proof of concept of running loleaflet.html in an iframe. Also
+<!-- Proof of concept of running cool.html in an iframe. Also
shows how to, from outside the iframe, invoke Python scripting in
the underlying LibreOffice instance that manipulates the document
being edited.
@@ -207,7 +207,7 @@
query = window.location.search + '&';
query += 'NotWOPIButIframe=true';
- var path = window.location.pathname.substr(0, window.location.pathname.lastIndexOf('/') + 1) + 'loleaflet.html';
+ var path = window.location.pathname.substr(0, window.location.pathname.lastIndexOf('/') + 1) + 'cool.html';
var uriBase = window.location.protocol + '//' + window.location.host + path + query;
var iframe = document.getElementById("frame");
iframe.src = uriBase;
diff --git a/loleaflet/html/framed.html b/loleaflet/html/framed.html
index 110959f33b..6f37d57c17 100644
--- a/loleaflet/html/framed.html
+++ b/loleaflet/html/framed.html
@@ -1,6 +1,6 @@
<!DOCTYPE html>
-<!-- Proof of concept of running loleaflet.html in an iframe. Also
+<!-- Proof of concept of running cool.html in an iframe. Also
shows how to, from outside the iframe, invoke Python scripting in
the underlying LibreOffice instance that manipulates the document
being edited.
@@ -201,7 +201,7 @@
<!-- 127.0.0.2 allows us to test CSS issues -->
<script>
- var uriBase = document.location.protocol + "//127.0.0.2:9980/loleaflet/42/loleaflet.html" + window.location.search;
+ var uriBase = document.location.protocol + "//127.0.0.2:9980/loleaflet/42/cool.html" + window.location.search;
var iframe = document.getElementById("frame");
iframe.src = uriBase + "&NotWOPIButIframe=true";
var msg = document.getElementById("link");
diff --git a/loleaflet/html/load.doc.html b/loleaflet/html/load.doc.html
index 84b0d90d60..d6ca007e02 100644
--- a/loleaflet/html/load.doc.html
+++ b/loleaflet/html/load.doc.html
@@ -44,7 +44,7 @@
}
function submitform() {
- var path = window.location.pathname.substr(0, window.location.pathname.lastIndexOf('/') + 1) + 'loleaflet.html';
+ var path = window.location.pathname.substr(0, window.location.pathname.lastIndexOf('/') + 1) + 'cool.html';
var query = '?access_token=' + document.getElementById("access_token").value;
query += '&file_path=' + document.getElementById("file_path").value;
query += '&NotWOPIButIframe=true';
diff --git a/loleaflet/html/multidocs.html b/loleaflet/html/multidocs.html
index 93a38d9afc..b73de19e58 100644
--- a/loleaflet/html/multidocs.html
+++ b/loleaflet/html/multidocs.html
@@ -1,6 +1,6 @@
<!DOCTYPE html>
-<!-- Proof of concept of running multiple instance of loleaflet.html
+<!-- Proof of concept of running multiple instance of cool.html
at the same time (each one in a different iframe).
To open the first document add the path into the input and click
@@ -192,7 +192,7 @@
query += 'file_path=file://' + path;
query += '&NotWOPIButIframe=true';
- var editorPath = window.location.pathname.substr(0, window.location.pathname.lastIndexOf('/') + 1) + 'loleaflet.html';
+ var editorPath = window.location.pathname.substr(0, window.location.pathname.lastIndexOf('/') + 1) + 'cool.html';
var src = window.location.protocol + '//' + window.location.host + editorPath + query;
return src;
diff --git a/loleaflet/js/global.js b/loleaflet/js/global.js
index e374d0b7d3..b89c90255a 100644
--- a/loleaflet/js/global.js
+++ b/loleaflet/js/global.js
@@ -723,7 +723,7 @@ window.app = { // Shouldn't have any functions defined.
}
};
- // Some global variables are defined in loleaflet.html, among them:
+ // Some global variables are defined in cool.html, among them:
// global.host: the host URL, with ws(s):// protocol
// global.serviceRoot: an optional root path on the server, typically blank.
diff --git a/loleaflet/src/map/handler/Map.WOPI.js b/loleaflet/src/map/handler/Map.WOPI.js
index 2da51b87ec..adcbab06d5 100644
--- a/loleaflet/src/map/handler/Map.WOPI.js
+++ b/loleaflet/src/map/handler/Map.WOPI.js
@@ -319,7 +319,7 @@ L.Map.WOPI = L.Handler.extend({
}
if (msg.MessageId === 'Host_PostmessageReady') {
- // We already have a listener for this in loleaflet.html, so ignore it here
+ // We already have a listener for this in cool.html, so ignore it here
return;
}
diff --git a/loleaflet/test/load.js b/loleaflet/test/load.js
index 415d8355c0..baa09f5ab7 100644
--- a/loleaflet/test/load.js
+++ b/loleaflet/test/load.js
@@ -64,7 +64,7 @@ global.console = {
const jsdom = require('jsdom');
const { JSDOM } = jsdom;
-var data = fs.readFileSync(top_builddir + '/loleaflet/dist/loleaflet.html', {encoding: 'utf8'});
+var data = fs.readFileSync(top_builddir + '/loleaflet/dist/cool.html', {encoding: 'utf8'});
data = data.replace(/%SERVICE_ROOT%\/loleaflet\/%VERSION%/g, top_builddir + '/loleaflet/dist');
data = data.replace(/%SERVICE_ROOT%/g, '');
@@ -95,7 +95,7 @@ window = new JSDOM(data, {
verbose: false,
pretendToBeVisual: false,
includeNodeLocations: false,
- url: 'file:///tmp/notthere/loleaflet.html?file_path=file:///' + to_load,
+ url: 'file:///tmp/notthere/cool.html?file_path=file:///' + to_load,
resources: 'usable',
beforeParse(window) {
console.debug('Before script parsing');
diff --git a/loolwsd.xml.in b/loolwsd.xml.in
index c8c3da9501..1e56b767ad 100644
--- a/loolwsd.xml.in
+++ b/loolwsd.xml.in
@@ -52,7 +52,7 @@
<idle_timeout_secs desc="The maximum number of seconds before dimming and stopping updates when the user is no longer active (even if the browser is in focus). Defaults to 15 minutes." type="uint" default="900">900</idle_timeout_secs>
</per_view>
- <loleaflet_html desc="Allows UI customization by replacing the single endpoint of loleaflet.html" type="string" default="loleaflet.html">loleaflet.html</loleaflet_html>
+ <loleaflet_html desc="Allows UI customization by replacing the single endpoint of cool.html" type="string" default="loleaflet.html">cool.html</loleaflet_html>
<ver_suffix desc="Appended to etags to allow easy refresh of changed files during development" type="string" default=""></ver_suffix>
<logging>
diff --git a/test/WhiteBoxTests.cpp b/test/WhiteBoxTests.cpp
index e0870e305d..c9181b5d66 100644
--- a/test/WhiteBoxTests.cpp
+++ b/test/WhiteBoxTests.cpp
@@ -1304,7 +1304,7 @@ void WhiteBoxTests::testRequestDetails_loleafletURI()
static const std::string URI
= "/loleaflet/49c225146/"
- "loleaflet.html?WOPISrc=http%3A%2F%2Flocalhost%2Fnextcloud%2Findex.php%2Fapps%"
+ "cool.html?WOPISrc=http%3A%2F%2Flocalhost%2Fnextcloud%2Findex.php%2Fapps%"
"2Frichdocuments%2Fwopi%2Ffiles%2F593_ocqiesh0cngs&title=empty.odt&lang=en-us&"
"closebutton=1&revisionhistory=1";
@@ -1325,7 +1325,7 @@ void WhiteBoxTests::testRequestDetails_loleafletURI()
LOK_ASSERT(details.equals(RequestDetails::Field::Type, "loleaflet"));
LOK_ASSERT(details.equals(0, "loleaflet"));
LOK_ASSERT_EQUAL(std::string("49c225146"), details[1]);
- LOK_ASSERT_EQUAL(std::string("loleaflet.html"), details[2]);
+ LOK_ASSERT_EQUAL(std::string("cool.html"), details[2]);
LOK_ASSERT_EQUAL(std::string("WOPISrc=http%3A%2F%2Flocalhost%2Fnextcloud%2Findex.php%"
"2Fapps%2Frichdocuments%2Fwopi%2Ffiles%2F593_ocqiesh0cngs&"
"title=empty.odt&lang=en-us&closebutton=1&revisionhistory=1"),
diff --git a/test/integration-http-server.cpp b/test/integration-http-server.cpp
index f977a84e79..f105955b67 100644
--- a/test/integration-http-server.cpp
+++ b/test/integration-http-server.cpp
@@ -119,7 +119,7 @@ public:
void HTTPServerTest::testLoleafletGet()
{
- const auto pathAndQuery = "/loleaflet/dist/loleaflet.html?access_token=111111111";
+ const auto pathAndQuery = "/loleaflet/dist/cool.html?access_token=111111111";
const std::shared_ptr<const http::Response> httpResponse
= http::get(_uri.toString(), pathAndQuery);
@@ -141,7 +141,7 @@ void HTTPServerTest::testLoleafletPost()
{
std::unique_ptr<Poco::Net::HTTPClientSession> session(helpers::createSession(_uri));
- Poco::Net::HTTPRequest request(Poco::Net::HTTPRequest::HTTP_POST, "/loleaflet/dist/loleaflet.html");
+ Poco::Net::HTTPRequest request(Poco::Net::HTTPRequest::HTTP_POST, "/loleaflet/dist/cool.html");
Poco::Net::HTMLForm form;
form.set("access_token", "2222222222");
form.prepareSubmit(request);
@@ -198,7 +198,7 @@ void HTTPServerTest::testScriptsAndLinksGet()
{
std::unique_ptr<Poco::Net::HTTPClientSession> session(helpers::createSession(_uri));
- Poco::Net::HTTPRequest request(Poco::Net::HTTPRequest::HTTP_GET, "/loleaflet/dist/loleaflet.html");
+ Poco::Net::HTTPRequest request(Poco::Net::HTTPRequest::HTTP_GET, "/loleaflet/dist/cool.html");
session->sendRequest(request);
Poco::Net::HTTPResponse response;
@@ -219,7 +219,7 @@ void HTTPServerTest::testScriptsAndLinksPost()
{
std::unique_ptr<Poco::Net::HTTPClientSession> session(helpers::createSession(_uri));
- Poco::Net::HTTPRequest request(Poco::Net::HTTPRequest::HTTP_POST, "/loleaflet/dist/loleaflet.html");
+ Poco::Net::HTTPRequest request(Poco::Net::HTTPRequest::HTTP_POST, "/loleaflet/dist/cool.html");
std::string body;
request.setContentLength((int) body.length());
session->sendRequest(request) << body;
diff --git a/wsd/LOOLWSD.cpp b/wsd/LOOLWSD.cpp
index 55cb66fa19..aadc3c1893 100644
--- a/wsd/LOOLWSD.cpp
+++ b/wsd/LOOLWSD.cpp
@@ -1053,7 +1053,7 @@ void LOOLWSD::innerInitialize(Application& self)
{ "logging.file[@enable]", "false" },
{ "logging.level", "trace" },
{ "logging.lokit_sal_log", "-INFO-WARN" },
- { "loleaflet_html", "loleaflet.html" },
+ { "loleaflet_html", "cool.html" },
{ "loleaflet_logging", "false" },
{ "mount_jail_tree", "true" },
{ "net.connection_timeout_secs", "30" },
@@ -3724,7 +3724,7 @@ private:
}
const auto& config = Application::instance().config();
- const std::string loleafletHtml = config.getString("loleaflet_html", "loleaflet.html");
+ const std::string loleafletHtml = config.getString("loleaflet_html", "cool.html");
const std::string action = "action";
const std::string favIconUrl = "favIconUrl";
diff --git a/wsd/RequestDetails.cpp b/wsd/RequestDetails.cpp
index 3736687346..b0bd1df3c7 100644
--- a/wsd/RequestDetails.cpp
+++ b/wsd/RequestDetails.cpp
@@ -261,7 +261,7 @@ Poco::URI RequestDetails::sanitizeURI(const std::string& uri)
throw std::runtime_error("Invalid URI.");
}
- // We decoded access token before embedding it in loleaflet.html
+ // We decoded access token before embedding it in cool.html
// So, we need to decode it now to get its actual value
Poco::URI::QueryParameters queryParams = uriPublic.getQueryParameters();
for (auto& param : queryParams)
diff --git a/wsd/RequestDetails.hpp b/wsd/RequestDetails.hpp
index be01e3359a..fc10d9439a 100644
--- a/wsd/RequestDetails.hpp
+++ b/wsd/RequestDetails.hpp
@@ -30,17 +30,17 @@
* Example:
* convert-to
*
- * loleaflet URI: used to load loleaflet.html and other static files.
+ * loleaflet URI: used to load cool.html and other static files.
* Origin: the page where the document will be embedded.
* Format:
* /loleaflet/<loolwsd-version-hash>/[path/]<filename>.<ext>[?WOPISrc=<encoded-document-URI>]
* Identifier: /loleaflet/.
* Examples:
* /loleaflet/49c225146/src/map/Clipboard.js
- * /loleaflet/49c225146/loleaflet.html?WOPISrc=http%3A%2F%2Flocalhost%2Fnextcloud%2Findex.php%2Fapps%2Frichdocuments%2Fwopi%2Ffiles%2F593_ocqiesh0cngs&title=empty.odt&lang=en-us&closebutton=1&revisionhistory=1
+ * /loleaflet/49c225146/cool.html?WOPISrc=http%3A%2F%2Flocalhost%2Fnextcloud%2Findex.php%2Fapps%2Frichdocuments%2Fwopi%2Ffiles%2F593_ocqiesh0cngs&title=empty.odt&lang=en-us&closebutton=1&revisionhistory=1
*
* lool URI: used to load the document.
- * Origin: loleaflet.html
+ * Origin: cool.html
* Format:
* /lool/<encoded-document-URI+options>/ws?WOPISrc=<encoded-document-URI>&compat=/ws[/<sessionId>/<command>/<serial>]
* Identifier: /lool/.
diff --git a/wsd/FileServer.cpp b/wsd/FileServer.cpp
index f4cda50447..37af17c262 100644
--- a/wsd/FileServer.cpp
+++ b/wsd/FileServer.cpp
@@ -554,7 +554,7 @@ void FileServerRequestHandler::handleRequest(const HTTPRequest& request,
if (FileHash.find(relPath) == FileHash.end())
throw Poco::FileNotFoundException("Invalid URI request: [" + requestUri.toString() + "].");
- const std::string loleafletHtml = config.getString("loleaflet_html", "loleaflet.html");
+ const std::string loleafletHtml = config.getString("loleaflet_html", "cool.html");
if (endPoint == loleafletHtml ||
endPoint == "help-localizations.json" ||
endPoint == "localizations.json" ||
@@ -868,9 +868,9 @@ void FileServerRequestHandler::preprocessFile(const HTTPRequest& request,
LOG_DBG("Preprocessing file: " << relPath);
std::string preprocess = *getUncompressedFile(relPath);
// We need to pass certain parameters from the loleaflet html GET URI
// to the embedded document URI. Here we extract those params
- // from the GET URI and set them in the generated html (see loleaflet.html.m4).
+ // from the GET URI and set them in the generated html (see cool.html.m4).
HTMLForm form(request, message);
const std::string accessToken = form.get("access_token", "");
const std::string accessTokenTtl = form.get("access_token_ttl", "");
@@ -887,7 +887,7 @@ void FileServerRequestHandler::preprocessFile(const HTTPRequest& request,
LOG_TRC("theme=" << theme);
// Escape bad characters in access token.
// This is placed directly in javascript in loleaflet.html, we need to make sure
// that no one can do anything nasty with their clever inputs.
std::string escapedAccessToken, escapedAccessHeader, escapedPostmessageOrigin;
Poco::URI::encode(accessToken, "'", escapedAccessToken);
@@ -868,9 +868,9 @@ void FileServerRequestHandler::preprocessFile(const HTTPRequest& request,
LOG_DBG("Preprocessing file: " << relPath);
std::string preprocess = *getUncompressedFile(relPath);
- // We need to pass certain parameters from the loleaflet html GET URI
+ // We need to pass certain parameters from the cool html GET URI
// to the embedded document URI. Here we extract those params
@@ -887,7 +887,7 @@ void FileServerRequestHandler::preprocessFile(const HTTPRequest& request,
LOG_TRC("theme=" << theme);
// Escape bad characters in access token.
- // This is placed directly in javascript in loleaflet.html, we need to make sure
+ // This is placed directly in javascript in cool.html, we need to make sure
// that no one can do anything nasty with their clever inputs.
std::string escapedAccessToken, escapedAccessHeader, escapedPostmessageOrigin;